@@ -49,18 +49,22 @@ class DeepLService(cloudlanguagetools.service.Service):
             DeepLTranslationLanguage(language.fi, 'FI'),
             DeepLTranslationLanguage(language.fr, 'FR'),
             DeepLTranslationLanguage(language.hu, 'HU'),
+            DeepLTranslationLanguage(language.id_, 'ID'),
             DeepLTranslationLanguage(language.it, 'IT'),
             DeepLTranslationLanguage(language.ja, 'JA'),
             DeepLTranslationLanguage(language.lt, 'LT'),
             DeepLTranslationLanguage(language.lv, 'LV'),
             DeepLTranslationLanguage(language.nl, 'NL'),
             DeepLTranslationLanguage(language.pl, 'PL'),
-            DeepLTranslationLanguage(language.pt_pt, 'PT'),
+            DeepLTranslationLanguage(language.pt_pt, 'PT-PT'),
+            DeepLTranslationLanguage(language.pt_br, 'PT-BR'),
             DeepLTranslationLanguage(language.ro, 'RO'),
             DeepLTranslationLanguage(language.ru, 'RU'),
             DeepLTranslationLanguage(language.sk, 'SK'),
             DeepLTranslationLanguage(language.sl, 'SL'),
             DeepLTranslationLanguage(language.sv, 'SV'),
+            DeepLTranslationLanguage(language.tr, 'TR'),
+            DeepLTranslationLanguage(language.uk, 'UK'),
             DeepLTranslationLanguage(language.zh_cn, 'ZH'),
         ]
         return result        
@@ -75,6 +79,14 @@ class DeepLService(cloudlanguagetools.service.Service):
         return []
 
     def get_translation(self, text, from_language_key, to_language_key):
+
+        override_source_language_map = {
+            'PT-PT': 'PT',
+            'PT-BR': 'PT'
+        }
+        from_language_key = override_source_language_map.get(from_language_key, from_language_key)
+
+
         params = {
             'auth_key': self.api_key,
             'text': text,
